@@ -12,6 +12,7 @@ from .conv import (
     optional,
     optional_str,
 )
+from .erratum_fixup import fixup_erratum_class
 
 
 @attr.s()
@@ -111,6 +112,9 @@ class ErratumPackage(object):
     :meth:`filename` for the source RPM itself.
     """
 
+    reboot_suggested = attr.ib(type=bool, default=False, validator=instance_of(bool))
+    """True if rebooting host machine is recommended after installing this package."""
+
     md5sum = attr.ib(type=str, default=None, converter=md5str)
     """MD5 checksum of this RPM in hex string form, if available."""
 
@@ -179,6 +183,7 @@ class ErratumPackageCollection(object):
                     version=raw_pkg["version"],
                     release=raw_pkg["release"],
                     src=raw_pkg["src"],
+                    reboot_suggested=raw_pkg.get("reboot_suggested") or False,
                     md5sum=sums.get("md5"),
                     sha1sum=sums.get("sha1"),
                     sha256sum=sums.get("sha256"),
@@ -219,7 +224,14 @@ class ErratumPushItem(PushItem):
     """Number of times advisory has been revised and published (starting at '1')."""
 
     reboot_suggested = attr.ib(type=bool, default=False, validator=instance_of(bool))
-    """True if rebooting host machine is recommended after installing this advisory."""
+    """True if rebooting host machine is recommended after installing this advisory.
+
+    .. warning::
+        The intended usage of this field is unclear.
+
+        In practice, tools such as yum are instead consuming the ``reboot_suggested`` field
+        from :class:`ErratumPackage`.
+    """
 
     references = attr.ib(
         type=list, default=attr.Factory(frozenlist), converter=frozenlist
@@ -231,7 +243,12 @@ class ErratumPushItem(PushItem):
     associated with the advisory."""
 
     from_ = attr.ib(type=str, default=None, validator=optional_str)
-    """Contact email address for the owner of the advisory."""
+    """Contact email address for the owner of the advisory.
+
+    Note that the canonical name for this attribute is ``from``. As this clashes
+    with a Python keyword, in most contexts the attribute is also available as an
+    alias, ``from_``. Where possible, the canonical name ``from`` should be preferred.
+    """
 
     rights = attr.ib(type=str, default=None, validator=optional_str)
     """Copyright message."""
@@ -308,6 +325,7 @@ class ErratumPushItem(PushItem):
             "reboot_suggested",
             "rights",
             "title",
+            "from",
             "description",
             "version",
             "updated",
@@ -318,9 +336,6 @@ class ErratumPushItem(PushItem):
         ]:
             kwargs[field] = data[field]
 
-        # Workaround to avoid python keyword
-        kwargs["from_"] = data["from"]
-
         # If the metadata has a cdn_repo field, this sets the destinations for the
         # push item; used for text-only errata.
         if data.get("cdn_repo"):
@@ -339,3 +354,7 @@ class ErratumPushItem(PushItem):
         )
 
         return cls(**kwargs)
+
+
+# Apply from vs from_ workarounds.
+fixup_erratum_class(ErratumPushItem)
